![](deemon/assets/images/logo.png "deemon")

[About](#about) | [Upgrading from 0.4.x](#migrating) | [Installation](#installation) | [Support](#support) | [Documentation](https://digitalec.github.io/deemon)

![PyPI](https://img.shields.io/pypi/v/deemon?style=flat-square)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/deemon?style=flat-square)
![PyPI - License](https://img.shields.io/pypi/l/deemon?style=flat-square)
![PyPI - Downloads](https://img.shields.io/pypi/dm/deemon?style=flat-square)
![GitHub last commit](https://img.shields.io/github/last-commit/digitalec/deemon?style=flat-square)
![Discord](https://img.shields.io/discord/831356172464160838?style=flat-square)



### About
deemon is an automation tool that relies on the deemix library and
the deezer-py API module to monitor a specified list of artists for new releases

### Support
[Open an Issue](https://github.com/digitalec/deemon/issues/new) | [Discord](https://discord.gg/KzNCG2tkvn)


### Upgrading from 0.4.x or earlier
Please note, the deemon CLI has changed significantly and no longer accepts many of the switches/commands that were previously used. This was done to provide a better, more natural, user experience.

Please take a look at the help via `deemon --help` or by reading the [documentation](https://digitalec.github.io/deemon).

### Installation

#### Using pip

```bash
$ pip install deemon
```

#### From source
```bash
$ pip install -r requirements.txt
